<?php

	/**
	 * Japanese language file for phpPgAdmin.
	 * @maintainer Tadashi Jokagi [elf2000@users.sourceforge.net]
	 *
	 * $Id: japanese.php,v 1.11.2.1 2005/02/09 13:18:12 chriskl Exp $
	 */

	// Language and character set
	$lang['applang'] = 'ܸ(EUC-JP)';
	$lang['appcharset'] = 'EUC-JP';
	$lang['applocale'] = 'ja_JP';
  	$lang['appdbencoding'] = 'EUC_JP';
	$lang['applangdir'] = 'ltr';
  
	// Welcome  
	$lang['strintro'] = '褦phpPgAdminء';
	$lang['strppahome'] = 'phpPgAdmin ۡڡ';
	$lang['strpgsqlhome'] = 'PostgreSQL ۡڡ';
	$lang['strpgsqlhome_url'] = 'http://www.postgresql.org/';
	$lang['strlocaldocs'] = 'PostgreSQL ɥ ()';
	$lang['strreportbug'] = 'Хݡ';
	$lang['strviewfaq'] = 'FAQ򸫤';
	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/?page=faq';
	
	// Basic strings
	$lang['strlogin'] = '';
	$lang['strloginfailed'] = '';
	$lang['strlogindisallowed'] = '󤬵ĤޤǤ';
	$lang['strserver'] = 'С';
	$lang['strlogout'] = '';
	$lang['strowner'] = 'ͭ';
	$lang['straction'] = '';
	$lang['stractions'] = '';
	$lang['strname'] = '̾';
	$lang['strdefinition'] = '';
	$lang['straggregates'] = '';
	$lang['strproperties'] = 'ץѥƥ';
	$lang['strbrowse'] = 'ɽ';
	$lang['strdrop'] = '˴';
	$lang['strdropped'] = '˴ޤ';
	$lang['strnull'] = 'NULL';
	$lang['strnotnull'] = 'NOT NULL';
	$lang['strprev'] = '';
	$lang['strnext'] = '';
	$lang['strfirst'] = '<< ǽ';
	$lang['strlast'] = 'Ǹ >>';
	$lang['strfailed'] = '';
	$lang['strcreate'] = '';
	$lang['strcreated'] = 'ޤ';
	$lang['strcomment'] = '';
	$lang['strlength'] = 'Ĺ';
	$lang['strdefault'] = 'ǥե';
	$lang['stralter'] = 'ѹ';
	$lang['strok'] = 'OK';
	$lang['strcancel'] = 'ä';
	$lang['strsave'] = '¸';
	$lang['strreset'] = 'ꥻå';
	$lang['strinsert'] = '';
	$lang['strselect'] = '';
	$lang['strdelete'] = '';
	$lang['strupdate'] = '';
	$lang['strreferences'] = '';
	$lang['stryes'] = 'Ϥ';
	$lang['strno'] = '';
	$lang['strtrue'] = '';
	$lang['strfalse'] = '';
	$lang['stredit'] = 'Խ';
	$lang['strcolumn'] = '';
	$lang['strcolumns'] = '';
	$lang['strrows'] = '쥳';
	$lang['strrowsaff'] = 'ƶ쥳';
	$lang['strobjects'] = '֥';
	$lang['strexample'] = ')';
	$lang['strback'] = '';
	$lang['strqueryresults'] = '';
	$lang['strshow'] = 'ɽ';
	$lang['strempty'] = 'ˤ';
	$lang['strlanguage'] = '';
	$lang['strencoding'] = '󥳡';
	$lang['strvalue'] = '';
	$lang['strunique'] = 'ˡ';
	$lang['strprimary'] = 'ץ饤ޥ';
	$lang['strexport'] = 'ݡ';
	$lang['strimport'] = 'ݡ';
	$lang['strsql'] = 'SQL';
	$lang['strgo'] = 'Go';
	$lang['stradmin'] = '';
	$lang['strvacuum'] = 'Х塼';
	$lang['stranalyze'] = '';
	$lang['strcluster'] = '饹';
	$lang['strclustered'] = 'Clustered?';
	$lang['strreindex'] = 'ƥǥå';
	$lang['strrun'] = '¥';
	$lang['stradd'] = 'ɲ';
	$lang['strevent'] = '٥';
	$lang['strwhere'] = 'Where';
	$lang['strinstead'] = '';
	$lang['strwhen'] = 'When';
	$lang['strformat'] = 'եޥå';
	$lang['strdata'] = 'ǡ';
	$lang['strconfirm'] = 'ǧ';
	$lang['strexpression'] = 'ɾ';
	$lang['strellipsis'] = '...';
	$lang['strseparator'] = ': ';
	$lang['strexpand'] = 'Ÿ';
	$lang['strcollapse'] = 'Ĥ';
	$lang['strexplain'] = '¹Ի';
	$lang['strexplainanalyze'] = 'ܺٽϲ';
	$lang['strfind'] = '';
	$lang['stroptions'] = 'ץ';
	$lang['strrefresh'] = 'ɽ';
	$lang['strdownload'] = '';
	$lang['strdownloadgzipped'] = 'gzip ǰ̤ƥ';
	$lang['strinfo'] = '';
	$lang['stroids'] = 'OID ';
	$lang['stradvanced'] = '٤ʰ';
	$lang['strvariables'] = 'ѿ';
	$lang['strprocess'] = 'ץ';
	$lang['strprocesses'] = 'ץ';
	$lang['strsetting'] = '';
	$lang['streditsql'] = 'SQL Խ';
	$lang['strruntime'] = '¹Ի: %s ms';
	$lang['strpaginate'] = 'Paginate results';
	$lang['struploadscript'] = 'or upload an SQL script:';
	$lang['strstarttime'] = 'ϻ';
	$lang['strfile'] = 'ե';
	$lang['strfileimported'] = 'ե򥤥ݡȤޤ';

	// Error handling
	$lang['strnoframes'] = 'ΥץꥱѤ뤿ˤϥե졼बѲǽʥ֥饦ɬפǤ';
	$lang['strbadconfig'] = 'config.inc.php 켰Ǥ config.inc.php-dist ƺɬפޤ';
	$lang['strnotloaded'] = 'ǡ١򥵥ݡȤ褦 PHP Υѥ롦󥹥ȡ뤬Ƥޤ(ƥˤäƤ php ѥå¾ php-pgsql ѥåΥ󥹥ȡ롦ʤɤɬפǤ)';
	$lang['strphpversionnotsupported'] = ' PHP ΥСϥݡȤƤޤ󡣥С %s ʾ˥åץ졼ɤƤ';
	$lang['strpostgresqlversionnotsupported'] = ' PostgreSQL ΥСϥݡȤƤޤ󡣥С %s ʾ˥åץ졼ɤƤ';
	$lang['strbadschema'] = '̵Υޤꤵޤ';
	$lang['strbadencoding'] = 'ǡ١ǥ饤ȥ󥳡ɤꤷޤǤ';
	$lang['strsqlerror'] = 'SQL 顼:';
	$lang['strinstatement'] = 'ʸ:';
	$lang['strinvalidparam'] = 'ץȥѥ᡼̵Ǥ';
	$lang['strnodata'] = '쥳ɤĤޤ';
	$lang['strnoobjects'] = '֥ȤĤޤ';
	$lang['strrownotunique'] = 'Υ쥳ɤˤϰռ̻Ҥޤ';
	$lang['strnoreportsdb'] = 'ݡȥǡ١Ƥޤ󡣥ǥ쥯ȥˤ INSTALL եɤǤ';
	$lang['strnouploads'] = 'ե륢åץɤ̵Ǥ';
	$lang['strimporterror'] = 'ݡȥ顼';
	$lang['strimporterrorline'] = '%s ܤݡȥ顼Ǥ';

	// Tables
	$lang['strtable'] = 'ơ֥';
	$lang['strtables'] = 'ơ֥';
	$lang['strshowalltables'] = 'ơ֥򸫤';
	$lang['strnotables'] = 'ơ֥뤬Ĥޤ';
	$lang['strnotable'] = 'ơ֥뤬Ĥޤ';
	$lang['strcreatetable'] = 'ơ֥';
	$lang['strtablename'] = 'ơ֥̾';
	$lang['strtableneedsname'] = 'ơ֥̾ꤹɬפޤ';
	$lang['strtableneedsfield'] = 'ʤȤĤΥեɤꤷʤФʤޤ';
	$lang['strtableneedscols'] = 'ͭʥꤷʤФʤޤ';
	$lang['strtablecreated'] = 'ơ֥ޤ';
	$lang['strtablecreatedbad'] = 'ơ֥κ˼Ԥޤ';
	$lang['strconfdroptable'] = 'ơ֥%sפ˴ޤ?';
	$lang['strtabledropped'] = 'ơ֥˴ޤ';
	$lang['strtabledroppedbad'] = 'ơ֥˴˼Ԥޤ';
	$lang['strconfemptytable'] = '˥ơ֥%sפƤ˴ޤ?';
	$lang['strtableemptied'] = 'ơ֥뤬ˤʤޤ.';
	$lang['strtableemptiedbad'] = 'ơ֥ˤǤޤǤ';
	$lang['strinsertrow'] = '쥳ɤ';
	$lang['strrowinserted'] = '쥳ɤޤ';
	$lang['strrowinsertedbad'] = '쥳ɤ˼Ԥޤ';
	$lang['streditrow'] = '쥳Խ';
	$lang['strrowupdated'] = '쥳ɤ򹹿ޤ';
	$lang['strrowupdatedbad'] = '쥳ɤι˼Ԥޤ';
	$lang['strdeleterow'] = '쥳ɺ';
	$lang['strconfdeleterow'] = 'ˤΥ쥳ɤޤ?';
	$lang['strrowdeleted'] = '쥳ɤޤ';
	$lang['strrowdeletedbad'] = '쥳ɤκ˼Ԥޤ';
	$lang['strinsertandrepeat'] = 'ȷ֤';
	$lang['strnumcols'] = 'Number of columns';
	$lang['strcolneedsname'] = 'You must specify a name for the column';
	$lang['strtypeneedscols'] = 'You must specify a valid number of fields.';
	$lang['strselectallfields'] = 'ƤΥեɤ';
	$lang['strselectneedscol'] = 'ʤȤ쥫ɬפǤ';
	$lang['strselectunary'] = 'ñΥڥ졼ͤĤȤǤޤ';
	$lang['straltercolumn'] = 'ѹ';
	$lang['strcolumnaltered'] = 'ѹޤ';
	$lang['strcolumnalteredbad'] = 'ѹ˼Ԥޤ';
	$lang['strconfdropcolumn'] = '˥%sפơ֥%sפ˴ƤǤ?';
	$lang['strcolumndropped'] = '˴ޤ';
	$lang['strcolumndroppedbad'] = '˴˼Ԥޤ';
	$lang['straddcolumn'] = 'ɲ';
	$lang['strcolumnadded'] = 'ɲäޤ';
	$lang['strcolumnaddedbad'] = 'ɲä˼Ԥޤ';
	$lang['strdataonly'] = 'ǡΤ';
	$lang['strcascade'] = '';
	$lang['strtablealtered'] = 'ơ֥ѹޤ';
	$lang['strtablealteredbad'] = 'ơ֥ѹ˼Ԥޤ';
	$lang['strdataonly'] = 'ǡΤ';
	$lang['strstructureonly'] = '¤Τ';
	$lang['strstructureanddata'] = '¤ȥǡ';
	$lang['strtabbed'] = 'Tabbed';
	$lang['strauto'] = 'ư';
	$lang['strconfvacuumtable'] = ' "%s"  vacuum ޤ?';
	$lang['strestimatedrowcount'] = 'Estimated Row Count';

	// Users
	$lang['struser'] = '桼';
	$lang['strusers'] = '桼';
	$lang['strusername'] = '桼̾';
	$lang['strpassword'] = 'ѥ';
	$lang['strsuper'] = 'ѡ桼?';
	$lang['strcreatedb'] = 'ǡ١ޤ?';
	$lang['strexpires'] = 'ͭ';
	$lang['strsessiondefaults'] = 'åǥե';
	$lang['strnousers'] = '桼Ĥޤ';
	$lang['struserupdated'] = '桼򹹿ޤ';
	$lang['struserupdatedbad'] = '桼ι˼Ԥޤ';
	$lang['strshowallusers'] = 'ƤΥ桼򸫤롣';
	$lang['strcreateuser'] = '桼';
	$lang['struserneedsname'] = '桼̾ɬפǤ';
	$lang['strusercreated'] = '桼ޤ';
	$lang['strusercreatedbad'] = '桼κ˼Ԥޤ';
	$lang['strconfdropuser'] = '˥桼%sפ˴ޤ?';
	$lang['struserdropped'] = '桼˴ޤ';
	$lang['struserdroppedbad'] = '桼κ˴ޤ';
	$lang['straccount'] = '';
	$lang['strchangepassword'] = 'ѥѹ';
	$lang['strpasswordchanged'] = 'ѥɤѹ򤷤ޤ';
	$lang['strpasswordchangedbad'] = 'ѥɤѹ˼Ԥޤ';
	$lang['strpasswordshort'] = 'ѥɤûޤ';
	$lang['strpasswordconfirm'] = 'ѥɤγǧפޤǤ';
		
	// Groups
	$lang['strgroup'] = '롼';
	$lang['strgroups'] = '롼װ';
	$lang['strnogroup'] = '롼פޤ';
	$lang['strnogroups'] = '롼פĤޤ';
	$lang['strcreategroup'] = '롼׺';
	$lang['strshowallgroups'] = '롼פ򸫤';
	$lang['strgroupneedsname'] = '롼̾ꤷʤФʤޤ';
	$lang['strgroupcreated'] = '롼פޤ';
	$lang['strgroupcreatedbad'] = '롼פκ˼Ԥޤ';	
	$lang['strconfdropgroup'] = '˥롼ס%sפ˴ޤ?';
	$lang['strgroupdropped'] = '롼פ˴ޤ';
	$lang['strgroupdroppedbad'] = '롼פ˴˼Ԥޤ';
	$lang['strmembers'] = 'С';
	$lang['straddmember'] = 'Сɲ';
	$lang['strmemberadded'] = 'Сɲäޤ';
	$lang['strmemberaddedbad'] = 'Сɲä˼Ԥޤ';
	$lang['strdropmember'] = 'С˴';
	$lang['strconfdropmember'] = '˥С%sפ򥰥롼ס%sפ˴ޤ?';
	$lang['strmemberdropped'] = 'С˴ޤ';
	$lang['strmemberdroppedbad'] = 'С˴˼Ԥޤ';

	// Privileges
	$lang['strprivilege'] = 'ø';
	$lang['strprivileges'] = 'ø';
	$lang['strnoprivileges'] = 'Υ֥ȤøäƤޤ';
	$lang['strgrant'] = '';
	$lang['strrevoke'] = 'ѻ';
	$lang['strgranted'] = 'øͿޤ';
	$lang['strgrantfailed'] = 'øͿ˼Ԥޤ';
	$lang['strgrantbad'] = 'ʤȤͤΥ桼롼פˡʤȤҤȤĤøꤷʤФʤޤ';
	$lang['strgrantor'] = 'Ϳ';
	$lang['strasterisk'] = '*';

	// Databases
	$lang['strdatabase'] = 'ǡ١';
	$lang['strdatabases'] = 'ǡ١';
	$lang['strshowalldatabases'] = 'ǡ١򸫤';
	$lang['strnodatabase'] = 'ǡ١Ĥޤ';
	$lang['strnodatabases'] = 'ǡ١ޤ';
	$lang['strcreatedatabase'] = 'ǡ١';
	$lang['strdatabasename'] = 'ǡ١̾';
	$lang['strdatabaseneedsname'] = 'ǡ١̾ꤷʤФʤޤ';
	$lang['strdatabasecreated'] = 'ǡ١ޤ';
	$lang['strdatabasecreatedbad'] = 'ǡ١κ˼Ԥޤ';	
	$lang['strconfdropdatabase'] = '˥ǡ١%sפ˴ޤ?';
	$lang['strdatabasedropped'] = 'ǡ١˴ޤ';
	$lang['strdatabasedroppedbad'] = 'ǡ١˴˼Ԥޤ';
	$lang['strentersql'] = '˼¹ԤSQLϤޤ:';
	$lang['strsqlexecuted'] = 'SQL¹Ԥޤ';
	$lang['strvacuumgood'] = 'Х塼λޤ';
	$lang['strvacuumbad'] = 'Х塼˼Ԥޤ';
	$lang['stranalyzegood'] = 'Ϥλޤ';
	$lang['stranalyzebad'] = 'Ϥ˼Ԥޤ';
	$lang['strreindexgood'] = 'ƥǥåλޤ';
	$lang['strreindexbad'] = 'ƥǥå˼Ԥޤ';
	$lang['strfull'] = '٤';
	$lang['strfreeze'] = 'ե꡼';
	$lang['strforce'] = '';
	$lang['strsignalsent'] = 'ʥ';
	$lang['strsignalsentbad'] = 'ʥ˼Ԥޤ';
	$lang['strallobjects'] = '٤ƤΥ֥Ȱ';

	// Views
	$lang['strview'] = 'ӥ塼';
	$lang['strviews'] = 'ӥ塼';
	$lang['strshowallviews'] = 'ӥ塼ɽ';
	$lang['strnoview'] = 'ӥ塼ޤ';
	$lang['strnoviews'] = 'ӥ塼Ĥޤ';
	$lang['strcreateview'] = 'ӥ塼';
	$lang['strviewname'] = 'ӥ塼̾';
	$lang['strviewneedsname'] = 'ӥ塼̾ꤷʤФʤޤ';
	$lang['strviewneedsdef'] = '̾ꤷʤФʤޤ';
	$lang['strviewneedsfields'] = 'ӥ塼Τ椫򤷡˾ΥꤷʤФʤޤ';
	$lang['strviewcreated'] = 'ӥ塼ޤ';
	$lang['strviewcreatedbad'] = 'ӥ塼κ˼Ԥޤ';
	$lang['strconfdropview'] = '˥ӥ塼%sפ˴ޤ?';
	$lang['strviewdropped'] = 'ӥ塼˴ޤ';
	$lang['strviewdroppedbad'] = 'ӥ塼˴˼Ԥޤ';
	$lang['strviewupdated'] = 'ӥ塼򹹿ޤ';
	$lang['strviewupdatedbad'] = 'ӥ塼ι˼Ԥޤ';
	$lang['strviewlink'] = 'Linking Keys';
	$lang['strviewconditions'] = 'ɲþ';
	$lang['strcreateviewwiz'] = 'ɤǥӥ塼';

	// Sequences
	$lang['strsequence'] = '';
	$lang['strsequences'] = '󥹰';
	$lang['strshowallsequences'] = '󥹤򸫤';
	$lang['strnosequence'] = '󥹤ޤ';
	$lang['strnosequences'] = '󥹤Ĥޤ';
	$lang['strcreatesequence'] = '󥹺';
	$lang['strlastvalue'] = 'ǽ';
	$lang['strincrementby'] = 'ÿ';	
	$lang['strstartvalue'] = '';
	$lang['strmaxvalue'] = '';
	$lang['strminvalue'] = 'Ǿ';
	$lang['strcachevalue'] = 'å';
	$lang['strlogcount'] = '';
	$lang['striscycled'] = 'Is Cycled?';
	$lang['striscalled'] = 'Is Called?';
	$lang['strsequenceneedsname'] = '̾ꤷʤФʤޤ';
	$lang['strsequencecreated'] = '󥹤ޤ';
	$lang['strsequencecreatedbad'] = '󥹤κ˼Ԥޤ'; 
	$lang['strconfdropsequence'] = '˥󥹡%sפ˴ޤ?';
	$lang['strsequencedropped'] = '󥹤˴ޤ';
	$lang['strsequencedroppedbad'] = '󥹤˴˼Ԥޤ';
	$lang['strsequencereset'] = '󥹥ꥻåȤԤޤ';
	$lang['strsequenceresetbad'] = '󥹤ΥꥻåȤ˼Ԥޤ'; 

	// Indexes
	$lang['strindex'] = 'ǥå';
	$lang['strindexes'] = 'ǥå';
	$lang['strindexname'] = 'ǥå̾';
	$lang['strshowallindexes'] = 'ǥåɽ';
	$lang['strnoindex'] = 'ǥåޤ';
	$lang['strnoindexes'] = 'ǥåĤޤ';
	$lang['strcreateindex'] = 'ǥå';
	$lang['strtabname'] = '̾';
	$lang['strcolumnname'] = '̾';
	$lang['strindexneedsname'] = 'ͭʥǥå̾ꤷʤФޤ';
	$lang['strindexneedscols'] = 'ͭʥꤷʤФޤ';
	$lang['strindexcreated'] = 'ǥåޤ';
	$lang['strindexcreatedbad'] = 'ǥå˼Ԥޤ';
	$lang['strconfdropindex'] = '˥ǥå%sפ˴ޤ?';
	$lang['strindexdropped'] = 'ǥå˴ޤ';
	$lang['strindexdroppedbad'] = 'ǥå˴˼Ԥޤ';
	$lang['strkeyname'] = '̾';
	$lang['struniquekey'] = 'ˡ';
	$lang['strprimarykey'] = 'ץ饤ޥꥭ';
 	$lang['strindextype'] = 'ǥå';
	$lang['strtablecolumnlist'] = 'ơ֥Υ';
	$lang['strindexcolumnlist'] = 'ǥåΥ';
	$lang['strconfcluster'] = 'ˡ%sפ򥯥饹ˤޤ?';
	$lang['strclusteredgood'] = '饹λǤ';
	$lang['strclusteredbad'] = '饹˼Ԥޤ';

	// Rules
	$lang['strrules'] = '롼';
	$lang['strrule'] = '롼';
	$lang['strshowallrules'] = '롼ɽ';
	$lang['strnorule'] = '롼뤬ޤ';
	$lang['strnorules'] = '롼뤬Ĥޤ';
	$lang['strcreaterule'] = '롼';
	$lang['strrulename'] = '롼̾';
	$lang['strruleneedsname'] = '롼̾ꤷʤФʤޤ';
	$lang['strrulecreated'] = '롼ޤ';
	$lang['strrulecreatedbad'] = '롼κ˼Ԥޤ';
	$lang['strconfdroprule'] = '˥롼%sפǡ١%sפ˴ޤ?';
	$lang['strruledropped'] = '롼˴ޤ';
	$lang['strruledroppedbad'] = '롼˴˼Ԥޤ';

	// Constraints
	$lang['strconstraints'] = '';
	$lang['strshowallconstraints'] = 'ɽ';
	$lang['strnoconstraints'] = '󤬤ޤ';
	$lang['strcreateconstraint'] = 'κ';
	$lang['strconstraintcreated'] = 'ޤ';
	$lang['strconstraintcreatedbad'] = 'κ˼Ԥޤ';
	$lang['strconfdropconstraint'] = '˸%sפǡ١%sפ˴ޤ?';
	$lang['strconstraintdropped'] = '˴ޤ';
	$lang['strconstraintdroppedbad'] = '˴˼Ԥޤ';
	$lang['straddcheck'] = 'åɲ';
	$lang['strcheckneedsdefinition'] = 'ˤɬפǤ';
	$lang['strcheckadded'] = 'ɲäޤ';
	$lang['strcheckaddedbad'] = 'ɲä˼Ԥޤ';
	$lang['straddpk'] = 'ץ饤ޥꥭɲ';
	$lang['strpkneedscols'] = 'ץ饤ޥꥭϾʤȤ쥫ɬפȤޤ';
	$lang['strpkadded'] = 'ץ饤ޥꥭɲäޤ';
	$lang['strpkaddedbad'] = 'ץ饤ޥꥭɲä˼Ԥޤ';
	$lang['stradduniq'] = 'ˡɲ';
	$lang['struniqneedscols'] = 'ˡϾʤȤ쥫ɬפȤޤ';
	$lang['struniqadded'] = 'ˡɲäޤ';
	$lang['struniqaddedbad'] = 'ˡɲä˼Ԥޤ';
	$lang['straddfk'] = 'ɲ';
	$lang['strfkneedscols'] = 'ϾʤȤ쥫ɬפȤޤ';
	$lang['strfkneedstarget'] = 'ϥåȥơ֥ɬפȤޤ';
	$lang['strfkadded'] = 'ɲäޤ';
	$lang['strfkaddedbad'] = 'ɲä˼Ԥޤ';
	$lang['strfktarget'] = 'оݥơ֥';
	$lang['strfkcolumnlist'] = 'Υ';
	$lang['strondelete'] = 'ON DELETE';
	$lang['stronupdate'] = 'ON UPDATE';	

	// Functions
	$lang['strfunction'] = 'ؿ';
	$lang['strfunctions'] = 'ؿ';
	$lang['strshowallfunctions'] = 'ؿɽ';
	$lang['strnofunction'] = 'ؿޤ';
	$lang['strnofunctions'] = 'ؿĤޤ';
	$lang['strcreateplfunction'] = 'SQL/PL ؿ';
	$lang['strcreateinternalfunction'] = 'Create internal function';
	$lang['strcreatecfunction'] = 'C ؿ';
	$lang['strfunctionname'] = 'ؿ̾';
	$lang['strreturns'] = '֤';
	$lang['strarguments'] = '';
	$lang['strproglanguage'] = 'ץߥ󥰸';
	$lang['strfunctionneedsname'] = 'ؿ̾ꤷʤФʤޤ';
	$lang['strfunctionneedsdef'] = 'ؿ򤷤ʤФʤꤢ';
	$lang['strfunctioncreated'] = 'ؿޤ';
	$lang['strfunctioncreatedbad'] = 'ؿκ˼Ԥޤ';
	$lang['strconfdropfunction'] = '˴ؿ%sפ˴ޤ?';
	$lang['strfunctiondropped'] = 'ؿ˴ޤ';
	$lang['strfunctiondroppedbad'] = 'ؿ˴˼Ԥޤ';
	$lang['strfunctionupdated'] = 'ؿ򹹿ޤ';
	$lang['strfunctionupdatedbad'] = 'ؿι˼Ԥޤ';
	$lang['strobjectfile'] = '֥ȥե';
	$lang['strlinksymbol'] = '󥯥ܥ';

	// Triggers
	$lang['strtrigger'] = 'ȥꥬ';
	$lang['strtriggers'] = 'ȥꥬ';
	$lang['strshowalltriggers'] = 'ȥꥬɽ';
	$lang['strnotrigger'] = 'ȥꥬޤ';
	$lang['strnotriggers'] = 'ȥꥬĤޤ';
	$lang['strcreatetrigger'] = 'ȥꥬ';
	$lang['strtriggerneedsname'] = 'ȥꥬ̾ꤹɬפޤ';
	$lang['strtriggerneedsfunc'] = 'ȥꥬΤδؿꤷʤФʤޤ';
	$lang['strtriggercreated'] = 'ȥꥬޤ';
	$lang['strtriggercreatedbad'] = 'ȥꥬκ˼Ԥޤ';
	$lang['strconfdroptrigger'] = '˥ȥꥬ%sפǡ١%sפ˴ޤ?';
	$lang['strtriggerdropped'] = 'ȥꥬ˴ޤ';
	$lang['strtriggerdroppedbad'] = 'ȥꥬ˴˼Ԥޤ';
	$lang['strtriggeraltered'] = 'ȥꥬѹޤ';
	$lang['strtriggeralteredbad'] = 'ȥꥬѹ˼Ԥޤ';

	// Types
	$lang['strtype'] = 'ǡ';
	$lang['strtypes'] = 'ǡ';
	$lang['strshowalltypes'] = 'ǡɽ';
	$lang['strnotype'] = 'ǡޤ';
	$lang['strnotypes'] = 'ǡĤޤǤ';
	$lang['strcreatetype'] = 'ǡκ';
	$lang['strcreatecomptype'] = 'ʣ緿';
	$lang['strtypeneedsfield'] = 'ʤȤ 1 ĤΥեɤꤷʤФʤޤ';
	$lang['strtypeneedscols'] = 'ͭʥեɤοꤷʤФʤޤ';
	$lang['strtypename'] = 'ǡ̾';
	$lang['strinputfn'] = 'ϴؿ';
	$lang['stroutputfn'] = 'ϴؿ';
	$lang['strpassbyval'] = 'Passed by val?';
	$lang['stralignment'] = '饤';
	$lang['strelement'] = '';
	$lang['strdelimiter'] = 'ǥߥ꥿';
	$lang['strstorage'] = 'ȥ졼';
	$lang['strfield'] = 'ե';
	$lang['strnumfields'] = 'եɿ';
	$lang['strtypeneedsname'] = '̾ꤷʤФʤޤ';
	$lang['strtypeneedslen'] = 'ǡĹꤷʤФʤޤ';
	$lang['strtypecreated'] = 'ǡޤ';
	$lang['strtypecreatedbad'] = 'ǡκ˼Ԥޤ';
	$lang['strconfdroptype'] = '˥ǡ%sפ˴ޤ?';
	$lang['strtypedropped'] = 'ǡ˴ޤ';
	$lang['strtypedroppedbad'] = 'ǡ˴˼Ԥޤ';
	$lang['strflavor'] = 'Flavor';
	$lang['strbasetype'] = '';
	$lang['strcompositetype'] = 'ʣ緿';
	$lang['strpseudotype'] = 'Pseudo';

	// Schemas
	$lang['strschema'] = '';
	$lang['strschemas'] = 'ް';
	$lang['strshowallschemas'] = 'ޤɽ';
	$lang['strnoschema'] = 'ޤޤ';
	$lang['strnoschemas'] = 'ޤĤޤ';
	$lang['strcreateschema'] = '޺';
	$lang['strschemaname'] = '̾';
	$lang['strschemaneedsname'] = '̾ꤹɬפޤ';
	$lang['strschemacreated'] = 'ޤޤ';
	$lang['strschemacreatedbad'] = 'ޤκ˼Ԥޤ';
	$lang['strconfdropschema'] = '˥ޡ%sפ˴ޤ?';
	$lang['strschemadropped'] = 'ޤ˴ޤ';
	$lang['strschemadroppedbad'] = 'ޤ˴˼Ԥޤ';
	$lang['strschemaaltered'] = 'ޤѹޤ';
	$lang['strschemaalteredbad'] = 'ޤѹ˼Ԥޤ';
        $lang['strsearchpath'] = '޸ѥ';

	// Reports
	$lang['strreport'] = 'ݡ';
	$lang['strreports'] = 'ݡȰ';
	$lang['strshowallreports'] = 'ݡȤ򸫤';
	$lang['strnoreports'] = 'ݡȤĤޤ';
	$lang['strcreatereport'] = 'ݡȺ';
	$lang['strreportdropped'] = 'ݡȤ˴ޤ';
	$lang['strreportdroppedbad'] = 'ݡȤ˴˼Ԥޤ';
	$lang['strconfdropreport'] = '˥ݡȡ%sפ˴ޤ?';
	$lang['strreportneedsname'] = 'ݡ̾ꤹɬפޤ';
	$lang['strreportneedsdef'] = 'ݡѤSQLꤹɬפޤ';
	$lang['strreportcreated'] = 'ݡȤ¸򤷤ޤ';
	$lang['strreportcreatedbad'] = 'ݡȤ¸˼Ԥޤ';

	// Domains
	$lang['strdomain'] = 'ɥᥤ';
	$lang['strdomains'] = 'ɥᥤ';
	$lang['strshowalldomains'] = 'ɥᥤ򸫤';
	$lang['strnodomains'] = 'ɥᥤ󤬤ޤ';
	$lang['strcreatedomain'] = 'ɥᥤ';
	$lang['strdomaindropped'] = 'ɥᥤ˴ޤ';
	$lang['strdomaindroppedbad'] = 'ɥᥤ˴˼Ԥޤ';
	$lang['strconfdropdomain'] = '˥ɥᥤ%sפ˴ޤ?';
	$lang['strdomainneedsname'] = 'ɥᥤ̾ꤹɬפޤ';
	$lang['strdomaincreated'] = 'ɥᥤޤ';
	$lang['strdomaincreatedbad'] = 'ɥᥤκ˼Ԥޤ';	
	$lang['strdomainaltered'] = 'ɥᥤѹޤ';
	$lang['strdomainalteredbad'] = 'ɥᥤѹ˼Ԥޤ';	

	// Operators
	$lang['stroperator'] = '黻';
	$lang['stroperators'] = '黻Ұ';
	$lang['strshowalloperators'] = '黻Ҥ򸫤';
	$lang['strnooperator'] = '黻ҤĤޤ';
	$lang['strnooperators'] = '黻ҥ饹Ĥޤ';
	$lang['strcreateoperator'] = '黻Ҥޤ';
	$lang['strleftarg'] = '';
	$lang['strrightarg'] = '';
	$lang['strcommutator'] = '';
	$lang['strnegator'] = '';
	$lang['strrestrict'] = '';
	$lang['strjoin'] = '';
	$lang['strhashes'] = 'ϥå';
	$lang['strmerges'] = 'ʻ';
	$lang['strleftsort'] = '';
	$lang['strrightsort'] = '';
	$lang['strlessthan'] = '̤';
	$lang['strgreaterthan'] = 'ʾ';
	$lang['stroperatorneedsname'] = '黻̾ꤹɬפޤ';
	$lang['stroperatorcreated'] = '黻Ҥޤ';
	$lang['stroperatorcreatedbad'] = '黻Ҥκ˼Ԥޤ';
	$lang['strconfdropoperator'] = '˱黻ҡ%sפ˴ޤ?';
	$lang['stroperatordropped'] = '黻Ҥ˴ޤ';
	$lang['stroperatordroppedbad'] = '黻Ҥ˴˼Ԥޤ';

	// Casts
	$lang['strcasts'] = '㥹Ȱ';
	$lang['strnocasts'] = '㥹ȤĤޤ';
	$lang['strsourcetype'] = '';
	$lang['strtargettype'] = 'åȥ';
	$lang['strimplicit'] = '';
	$lang['strinassignment'] = 'In assignment';
	$lang['strbinarycompat'] = '(Хʥߴ)';
	
	// Conversions
	$lang['strconversions'] = 'Ѵ';
	$lang['strnoconversions'] = 'ѴĤޤ';
	$lang['strsourceencoding'] = 'Ѵ󥳡';
	$lang['strtargetencoding'] = 'Ѵ襨󥳡';
	
	// Languages
	$lang['strlanguages'] = '';
	$lang['strnolanguages'] = '줬¸ߤޤ';
	$lang['strtrusted'] = 'Trusted';
	
	// Info
	$lang['strnoinfo'] = 'ͭʾ󤬤ޤ';
	$lang['strreferringtables'] = 'ȥơ֥';
	$lang['strparenttables'] = 'ƥơ֥';
	$lang['strchildtables'] = 'ҥơ֥';

	// Aggregates
	$lang['straggregates'] = 'װ';
	$lang['strnoaggregates'] = 'פޤ';
	$lang['stralltypes'] = '(ƤΥ)';

	// Operator Classes
	$lang['stropclasses'] = '黻ҥ饹';
	$lang['strnoopclasses'] = '黻ҥ饹Ĥޤ';
	$lang['straccessmethod'] = 'ˡ';

	// Stats and performance
	$lang['strrowperf'] = 'ԥѥեޥ';
	$lang['strioperf'] = 'I/O ѥեޥ';
	$lang['stridxrowperf'] = 'ǥåԥѥեޥ';
	$lang['stridxioperf'] = 'ǥå I/O ѥեޥ';
	$lang['strpercent'] = '%';
	$lang['strsequential'] = '󥷥';
	$lang['strscan'] = '';
	$lang['strread'] = 'ɹ';
	$lang['strfetch'] = '';
	$lang['strheap'] = 'ҡ';
	$lang['strtoast'] = 'TOAST';
	$lang['strtoastindex'] = 'TOAST ǥå';
	$lang['strcache'] = 'å';
	$lang['strdisk'] = 'ǥ';
	$lang['strrows2'] = '';

	// Tablespaces
	$lang['strtablespaces'] = 'ơ֥';
	$lang['strtablespace'] = 'ơ֥';
	$lang['strshowalltablespaces'] = '٤ƤΥơ֥륹ڡɽ';
	$lang['strnotablespaces'] = 'ơ֥֤Ĥޤ';
	$lang['strcreatetablespace'] = 'ơֺ֥';
	$lang['strlocation'] = '';
	$lang['strtablespaceneedsname'] = 'ơ֥̾ꤹɬפޤ';
	$lang['strtablespaceneedsloc'] = 'ơֺ֥򤹤ǥ쥯ȥꤹɬפޤ';
	$lang['strtablespacecreated'] = 'ơ֥֤ޤ';
	$lang['strtablespacecreatedbad'] = 'ơ֥֤κ˼Ԥޤ';
	$lang['strconfdroptablespace'] = '˥ơ֥֡%sפ˴ޤ?';
	$lang['strtablespacedropped'] = 'ơ֥֤˴ޤ';
	$lang['strtablespacedroppedbad'] = 'ơ֥֤˴˼Ԥޤ';
	$lang['strtablespacealtered'] = 'ơ֥֤ѹޤ';
	$lang['strtablespacealteredbad'] = 'ơ֥֤ѹ˼Ԥޤ';

	// Miscellaneous
	$lang['strtopbar'] = '%s  %s ݡֹ %s ³ -- 桼%sפǥۥȡ%sפ˥';
	$lang['strtimefmt'] = 'Y ǯ n  j  G:i';
	$lang['strhelp'] = 'إ';
	$lang['strhelpicon'] = '?';
?>
